@@ -2,8 +2,9 @@ from pystog.stog import StoG
 from pystog.converter import Converter
 from pystog.transformer import Transformer
 from pystog.fourier_filter import FourierFilter
+from pystog.pre_proc import Pre_Proc
 
-__all__ = ['StoG', 'Converter', 'Transformer', 'FourierFilter', ]
+__all__ = ['StoG', 'Converter', 'Transformer', 'FourierFilter', 'Pre_Proc', ]
 
 from ._version import get_versions
 __version__ = get_versions()['version']
